package com.njyunzhi.nanyang.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.njyunzhi.nanyang.common.AmapUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import com.njyunzhi.nanyang.entity.TaLocation;
import com.njyunzhi.nanyang.mapper.TaLocationMapper;
import com.njyunzhi.nanyang.service.TaLocationService;

import java.util.List;

/**
 * 地理位置;(ta_location)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-4-15
 */
@Slf4j
@Service
public class TaLocationServiceImpl extends BaseServiceImpl<TaLocationMapper, TaLocation> implements TaLocationService {

    @Autowired
    AmapUtil amapUtil;

    @Async
    @Override
    public void syncLocation() {
        List<String> locList = baseMapper.getUngeo();
        long length = null == locList ? 0 : locList.size();
        log.info("获取到待定位信息 {} 条", length);

        if (length == 0) return;

        for (String loc : locList) {
            JSONObject res = amapUtil.regeo(loc);
            if (null == res) continue;

            JSONObject res2 = res.getJSONObject("addressComponent");

            TaLocation taLocation = new TaLocation();
            taLocation.setLocation(loc);
            taLocation.setAddress(res.getString("formatted_address"));
            taLocation.setCountry(res2.getString("country"));
            taLocation.setProvince(res2.getString("province"));
            taLocation.setCityCode(res2.getString("citycode"));
            taLocation.setDistrict(res2.getString("district"));
            taLocation.setAdcode(res2.getString("adcode"));
            taLocation.setTown(res2.getString("township"));
            taLocation.setTownCode(res2.getString("towncode"));

            try {
                String city = res2.getString("city");
                if (null == city || "".equals(city)) {
                    taLocation.setCity(taLocation.getProvince());
                } else {
                    taLocation.setCity(city);
                }
            } catch (Exception e) {
                //
                taLocation.setCity(taLocation.getProvince());
            }

            baseMapper.insert(taLocation);

            try {
                Thread.sleep(500);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }
}